@@ -16,8 +16,7 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include <stdio.h>
@@ -347,13 +346,18 @@ fr_command_7z_add (FrCommand     *comm,
 
 	switch (comm->compression) {
 	case FR_COMPRESSION_VERY_FAST:
-		fr_process_add_arg (comm->process, "-mx=1"); break;
+		fr_process_add_arg (comm->process, "-mx=1");
+		break;
 	case FR_COMPRESSION_FAST:
-		fr_process_add_arg (comm->process, "-mx=5"); break;
+		fr_process_add_arg (comm->process, "-mx=5");
+		break;
 	case FR_COMPRESSION_NORMAL:
-		fr_process_add_arg (comm->process, "-mx=5"); break;
+		fr_process_add_arg (comm->process, "-mx=7");
+		break;
 	case FR_COMPRESSION_MAXIMUM:
-		fr_process_add_arg (comm->process, "-mx=7"); break;
+		fr_process_add_arg (comm->process, "-mx=9");
+		fr_process_add_arg (comm->process, "-m0=lzma2");;
+		break;
 	}
 
 	if (is_mime_type (comm->mime_type, "application/x-ms-dos-executable"))
@@ -526,6 +530,7 @@ const char *sevenz_mime_types[] = { "application/x-7z-compressed",
 				    /*"application/x-cbr",*/
 				    "application/x-cbz",
 				    "application/x-ms-dos-executable",
+				    "application/x-ms-wim",
 				    "application/x-rar",
 				    "application/zip",
 				    NULL };
